import json
from string import Template

Episode = Template(
"""
<div id="$number" class="episode">
    <h2>$title</h2>
    <h3>$subtitle</h3>
    <audio controls preload="none" src="$filename">no browser support</audio>
    <p>Published on: $published_on</p>
    <p>Download: <a href="$filename">this mirror</a> <a href="$url">original</a></p>
    <p>Show notes / summary, usually with track list:</p>
    <p>$summary</p>
</div>
""")

Page = Template(
"""
<!DOCTYPE html>
<html dir="ltr" lang="en">
<meta charset="utf-8" />
<style>
html,body {
    font-family: monospace, sans-serif;
    color: white;
    background: black;
}

.episode {
	border: solid grey;
	padding: 8px;
	margin-bottom: 10px;
}

h2 {
	text-decoration: underline;
}

</style>
<body>
<h1>Radio Three Sixty Archive</h1>
<img src="cover.jpg" alt="cover for radio three sixty" />
<p>This is an archive of <a href="https://radiothreesixty.com/">Radio Three Sixty</a>, a music podcast that aired from 2006 until 2016.</p>
<p>This archive contains all released episodes and show notes, with links to the original file from the rss feed.</p>
<p>You can grab the arcive by running <a href="archive_radio_three_sixty.py">archive_radio_three_sixty.py</a>. Last tested with python 3.8</p>
<p>This page was generated with <a href="build_player.py">build_player.py</a></p>
<p><details><summary>TOC</summary><ul>$toc</ul></details></p>
$episodes
</body>
</html>
""")

def episode_as_html(episode) -> str:
    episode["summary"] = episode["summary"].replace("\n", "<br />\n")
    return Episode.substitute(episode)

def toc(episodes):
    return [f"<li><a href='#{e['number']}'>{e['number']}</a></li>" for e in episodes]


def main():
    with open("manifest.json", "r") as raw:
        manifest = json.load(raw)
    episodes = [episode_as_html(ep) for ep in manifest]
    print(Page.substitute({
        "episodes": "\n".join(episodes),
        "toc": "\n".join(toc(manifest)),
        }))

if __name__ == "__main__":
    main()
